@@ -1,67 +1,63 @@
 package App::SimplenoteSync::Note;
-$App::SimplenoteSync::Note::VERSION = '0.2.1';
+{
+    $App::SimplenoteSync::Note::VERSION = '0.1';
+}
+
 # ABSTRACT: stores notes in plain files,
 
 use v5.10;
 use Moose;
 use MooseX::Types::Path::Class;
-use Try::Tiny;
 use namespace::autoclean;
 
 extends 'WebService::Simplenote::Note';
 
-use Method::Signatures;
-
-has '+title' => (trigger => \&_title_to_filename,);
+has '+title' => ( trigger => \&title_to_filename, );
 
 has file => (
-    is        => 'rw',
-    isa       => 'Path::Class::File',
-    coerce    => 1,
-    traits    => ['NotSerialised'],
-    trigger   => \&_has_markdown_ext,
-    predicate => 'has_file',
+    is      => 'rw',
+    isa     => 'Path::Class::File',
+    coerce  => 1,
+    trigger => \&_has_markdown_ext,
 );
 
 has file_extension => (
     is      => 'ro',
     isa     => 'HashRef',
-    traits  => ['NotSerialised'],
+    traits  => ['DoNotSerialize'],
     default => sub {
         {
             default  => 'txt',
             markdown => 'mkdn',
         };
-    },
+    }
 );
 
+# XXX should we serialise this?
 has notes_dir => (
     is       => 'ro',
     isa      => 'Path::Class::Dir',
-    traits   => ['NotSerialised'],
+    traits   => ['DoNotSerialize'],
     required => 1,
-    default  => sub {
-        my $self = shift;
-        if ($self->has_file) {
-            return $self->file->dir;
-        } else {
-            return Path::Class::Dir->new($ENV{HOME}, 'Notes');
-        }
-    },
+    default  => sub { return $_[0]->file->dir },
 );
 
-has ignored => (
-    is      => 'rw',
-    isa     => 'Bool',
-    traits  => ['NotSerialised'],
-    default => 0,
+MooseX::Storage::Engine->add_custom_type_handler(
+    'Path::Class::File' => (
+        expand   => sub { Path::Class::File->new( $_[0] ) },
+        collapse => sub { $_[0]->stringify }
+    )
 );
 
 # set the markdown systemtag if the file has a markdown extension
-method _has_markdown_ext(@_) {
+sub _has_markdown_ext {
+    my $self = shift;
+
+    # TODO an array of possibilities? e.g. mkdn, markdown, md
+    # maybe from system mime info?
     my $ext = $self->file_extension->{markdown};
 
-    if ($self->file =~ m/\.$ext$/ && !$self->is_markdown) {
+    if ( $self->file =~ m/\.$ext$/ && !$self->is_markdown ) {
         $self->set_markdown;
     }
 
@@ -69,10 +65,11 @@ method _has_markdown_ext(@_) {
 }
 
 # Convert note's title into file
-method _title_to_filename(Str $title, Str $old_title?) {
+sub title_to_filename {
+    my ( $self, $title, $old_title ) = @_;
 
     # don't change if already set
-    if (defined $self->file) {
+    if ( defined $self->file ) {
         return;
     }
 
@@ -83,46 +80,15 @@ method _title_to_filename(Str $title, Str $old_title?) {
     $file =~ s/\W/_/g;
     $file .= '.';
 
-    if (grep '/markdown/', @{$self->systemtags}) {
+    if ( grep '/markdown/', @{ $self->systemtags } ) {
         $file .= $self->file_extension->{markdown};
-        $self->logger->debug('Note is markdown');
+        $self->logger->debug( 'Note is markdown' );
     } else {
         $file .= $self->file_extension->{default};
-        $self->logger->debug('Note is plain text');
+        $self->logger->debug( 'Note is plain text' );
     }
 
-    $self->file($self->notes_dir->file($file));
-
-    return 1;
-}
-
-method load_content {
-    my $content;
-
-    try {
-        $content = $self->file->slurp(iomode => '<:utf8');
-    }
-    catch {
-        $self->logger->error("Failed to read file: $_");
-        return;
-    };
-
-    $self->content($content);
-    return 1;
-}
-
-method save_content {
-    try {
-        my $fh = $self->file->open('w');
-
-        # data from simplenote should always be utf8
-        $fh->binmode(':utf8');
-        $fh->print($self->content);
-    }
-    catch {
-        $self->logger->error("Failed to write content to file: $_");
-        return;
-    };
+    $self->file( $self->notes_dir->file( $file ) );
 
     return 1;
 }
@@ -135,8 +101,6 @@ __END__
 
 =pod
 
-=encoding UTF-8
-
 =for :stopwords Ioan Rogers Fletcher T. Penney github
 
 =head1 NAME
@@ -145,7 +109,7 @@ App::SimplenoteSync::Note - stores notes in plain files,
 
 =head1 VERSION
 
-version 0.2.1
+version 0.1
 
 =head1 AUTHORS
 
@@ -163,7 +127,7 @@ Fletcher T. Penney <owner@fletcherpenney.net>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2021 by Ioan Rogers.
+This software is Copyright (c) 2012 by Ioan Rogers.
 
 This is free software, licensed under:
 
@@ -176,7 +140,7 @@ web interface at L<https://github.com/ioanrogers/App-SimplenoteSync/issues>.
 
 =head1 SOURCE
 
-The development version is on github at L<https://github.com/ioanrogers/App-SimplenoteSync>
+The development version is on github at L<http://github.com/ioanrogers/App-SimplenoteSync>
 and may be cloned from L<git://github.com/ioanrogers/App-SimplenoteSync.git>
 
 =cut
